From: Davide Libenzi <davidel@xmailserver.org>
To: Eric Dumazet <dada1@cosmosbay.com>
Cc: Linux Kernel Mailing List <linux-kernel@vger.kernel.org>,
Linus Torvalds <torvalds@linux-foundation.org>,
Andrew Morton <akpm@linux-foundation.org>
Subject: Re: [patch] epoll reduced (to 1) number of passes over the ready set ...
Date: Wed, 28 Feb 2007 07:29:03 -0800 (PST) [thread overview]
Message-ID: <Pine.LNX.4.64.0702280727590.5935@alien.or.mcafeemobile.com> (raw)
In-Reply-To: <200702281213.59695.dada1@cosmosbay.com>
On Wed, 28 Feb 2007, Eric Dumazet wrote:
> On Tuesday 27 February 2007 17:03, Davide Libenzi wrote:
> > On Tue, 27 Feb 2007, Eric Dumazet wrote:
> > > On Tuesday 27 February 2007 03:32, Davide Libenzi wrote:
> > > > Epoll is doing multiple passes over the ready set at the moment,
> > > > because of the constraints over the f_op->poll() call. Looking at the
> > > > code again, I noticed that we already hold the epoll semaphore in read,
> > > > and this (together with other locking conditions that hold while doing
> > > > an epoll_wait()) can lead to a smarter way to "ship" events to
> > > > userspace (in a single pass). I added more (even) more comments to the
> > > > code to explain the conditions why certain operations are safe.
> > > > This is a stress application that can be used to test the new code. It
> > > > spwans multiple thread and call epoll_wait() and epoll_ctl() from many
> > > > threads. Stress tested on my dual Opteron 254 w/out any problems.
> > >
> > > Davide,
> > >
> > > This is really cool, because the size of epitem would fit now in 128
> > > bytes instead of 192 (on x86_64 platforms). So we also reduce memory
> > > usage.
> >
> > Yeah, I forgot to mention that I removed the txlink member.
>
> I am pretty sure you can also remove revents member from epitem.
>
> It would greatly benefit to 32bits platforms, because resulting size would be
> 64 bytes instead of 68 (so a 50 % reduction because of 64 bytes alignment)
Yes indee. That does not need to exist anymore, once the de-coupled loop
is gone. Thx, I'll make a new patch later today.
- Davide
prev parent reply other threads:[~2007-02-28 15:29 UTC|newest]
Thread overview: 7+ messages / expand[flat|nested] mbox.gz Atom feed top
2007-02-27 2:32 Davide Libenzi
2007-02-27 4:00 ` Linus Torvalds
2007-02-27 4:14 ` Davide Libenzi
2007-02-27 9:15 ` Eric Dumazet
2007-02-27 16:03 ` Davide Libenzi
2007-02-28 11:13 ` Eric Dumazet
2007-02-28 15:29 ` Davide Libenzi [this message]
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=Pine.LNX.4.64.0702280727590.5935@alien.or.mcafeemobile.com \
--to=davidel@xmailserver.org \
--cc=akpm@linux-foundation.org \
--cc=dada1@cosmosbay.com \
--cc=linux-kernel@vger.kernel.org \
--cc=torvalds@linux-foundation.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
all inboxes | Powered by JetHome®